GO-PCA |version| User Manual
============================

.. "**Exploring Gene Expression Data Using Prior Knowledge**

.. figure:: /_static/gopca.png
    :width: 400 px
    :align: right
    
    Detail from a GO-PCA *signature plot*.

This is the user manual for `GO-PCA`__, a
**free and open-source Python implementation** of the eponymous `method`__ for
exploring gene expression data using prior knowledge.

__ go_pca_
__ go_pca_paper_

.. _go_pca: https://github.com/flo-compbio/gopca

Contents
--------

.. toctree::
    :maxdepth: 2
    :includehidden:

    Introduction <intro>
    Installation <install>
    Obtaining Gene Sets <gene_sets>
    running
    The GO-PCA Python API <api/index>
    Citing GO-PCA <citing>
    License <license>

.. note::

    This manual uses "*GO-PCA*", in *italics*, to specifically reference the
    general methodology described in `Wagner (2015)`__. In all other cases,
    "GO-PCA" is meant to reference the Python software documented here.


__ go_pca_paper_

.. #rubric:: Recently Updated:
  
  * 2/15/2016: Expanded documentation on obtaining gene sets (see
    :doc:`gene_sets`)

.. _go_pca_paper: https://dx.doi.org/10.1371/journal.pone.0143196

.. GO-PCA Demos <demos>
    License <license>

..  intro
    Home <self>
    tutorial
    Modules <modules>
    autodoc


.. "Indices and tables
    ==================
    
    * :ref:`genindex`
    * :ref:`search`
    
    .. "* :ref:`modindex`
